% % Testing
% clear all; clc;
% FibCrackS = dlmread('FibCrackS.txt');
% FibCrackL = dlmread('FibCrackL.txt');
% FibCrackIn = dlmread('FibCrackIn.txt');
% FibCrackPar = dlmread('FibCrackPar.txt');
% eta = 0.0272;
% sc = 0.5;
% src = 0.3;
% dc = 0.01;
% cc = 0.0001;

% tic

function [cohesion, FibCrackIn] = CompTW(FibCrackS, FibCrackL, FibCrackIn, FibCrackPar, eta, sc, src, dc, cc)

% function calculates fiber - bridging cohesion force
%
% in:   FibCrackS - parameters on short embedded side (see SelFib.m)
%       FibCrackL - parameters on short embedded side (see SelFib.m)
%       FibCrackIn - pulling and rupture parameters (see SelFib.m)
%       FibCrackPar - material parameters (see SelFib.m)
%       eta - 
%       sc - [-] snubbing coefficient
%       src - [-] strength reduction coefficient
%       dc - increment of crack opening
%       cc - convergence criterion
% out:  cohesion
%            Column 1 - u - displacement [mm]
%            Column 2 - Ps - force on a short side[kN]
%            Column 3 - Pl - force on a long side[kN]
%       FibCrackIn
%            Column 1 - rupture parameter
%            Column 2 - pulling parameter


n = size(FibCrackS,1);

%%                  Pre - computation
% Seletion of fiber, which don't contribute in first step

for i=1:n
	if (FibCrackPar(i, 8)==0 || (sqrt((pi^2*FibCrackPar(i, 6)*FibCrackPar(i, 4)*FibCrackPar(i, 1)^3*(1+eta))/2*FibCrackS(i, 2)+(pi^2*FibCrackPar(i, 7)*FibCrackPar(i, 4)*FibCrackPar(i, 1)^3*(1+eta))/2)*exp(sc*FibCrackPar(i, 2))>(((FibCrackPar(i, 8)*FibCrackS(i, 1)+FibCrackPar(i, 1))^2*pi*FibCrackPar(i, 6))/(4*FibCrackPar(i, 8))*exp(sc*FibCrackPar(i, 2))) || (FibCrackPar(i, 8)*(FibCrackS(i, 1)+2*FibCrackS(i, 2))-FibCrackPar(i, 1))/(2*FibCrackPar(i, 8))<FibCrackS(i, 2)))
		um=FibCrackS(i, 1)+FibCrackS(i, 2)+FibCrackS(i, 2);
	else
		if (((FibCrackPar(i, 8)*FibCrackS(i, 1)+FibCrackPar(i, 1))^2*pi*FibCrackPar(i, 6))/(4*FibCrackPar(i, 8))*exp(sc*FibCrackPar(i, 2)))<sqrt((pi^2*FibCrackPar(i, 6)*FibCrackPar(i, 4)*FibCrackPar(i, 1)^3*(1+eta))/2*FibCrackL(i, 2)+(pi^2*FibCrackPar(i, 7)*FibCrackPar(i, 4)*FibCrackPar(i, 1)^3*(1+eta))/2)*exp(sc*FibCrackPar(i, 2));
			um=FibCrackS(i, 1)+FibCrackS(i, 2)+(2*(((FibCrackPar(i, 8)*FibCrackS(i, 1)+FibCrackPar(i, 1))^2*pi*FibCrackPar(i, 6))/(4*FibCrackPar(i, 8))*exp(sc*FibCrackPar(i, 2)))^2-pi^2*FibCrackPar(i, 4)*FibCrackPar(i, 1)^3*(1+eta)*FibCrackPar(i, 7))/(pi^2*FibCrackPar(i, 4)*FibCrackPar(i, 1)^3*(1+eta)*FibCrackPar(i, 6));
		else
			um=FibCrackS(i, 1)+FibCrackS(i, 2)-(sqrt((FibCrackPar(i, 8)^2*FibCrackL(i, 1)^2+2*FibCrackPar(i, 8)*FibCrackPar(i, 1)*FibCrackL(i, 1)+FibCrackPar(i, 1)^2)*pi*FibCrackPar(i, 6)-4*FibCrackPar(i, 8)*(((FibCrackPar(i, 8)*FibCrackS(i, 1)+FibCrackPar(i, 1))^2*pi*FibCrackPar(i, 6))/(4*FibCrackPar(i, 8))*exp(sc*FibCrackPar(i, 2))))-(FibCrackPar(i, 8)*(FibCrackL(i, 1)+2*FibCrackL(i, 2))-FibCrackPar(i, 1))*sqrt(pi*FibCrackPar(i, 6)))/(2*FibCrackPar(i, 8)*sqrt(pi*FibCrackPar(i, 6)));
		end
	end
	if dc>=um
		FibCrackIn(i, 2)=1;
	end
end

%%                  Computation

j = 2; %it starts from the second step
cohesion = zeros(1,5);
for COD = dc:dc:max(FibCrackS(:, 1))*1.5
	P1 = 0; P2 = 0;
	for i = 1:n
		if ( FibCrackIn(i, 1)~=1 && FibCrackIn(i, 2)~=1 )
			OK = 0;
			dus = min([0.01 FibCrackS(i, 2) COD/10]);
			us = COD; ul = COD-us;
			while OK~=1
								
				% Short side
				if ((us-FibCrackS(i, 3))<0) % unloading and reloading
					if (FibCrackS(i, 3)<=FibCrackS(i, 2)), Ps=sqrt((pi^2*FibCrackPar(i, 6)*FibCrackPar(i, 4)*FibCrackPar(i, 1)^3*(1+eta))/2*FibCrackS(i, 3)+(pi^2*FibCrackPar(i, 7)*FibCrackPar(i, 4)*FibCrackPar(i, 1)^3*(1+eta))/2)*exp(sc*FibCrackPar(i, 2))+(us-FibCrackS(i, 3))*((10*FibCrackPar(i, 4))*(pi*FibCrackPar(i, 1)^2/4));
					elseif (FibCrackS(i, 3)<=FibCrackS(i, 1)+FibCrackS(i, 2)), Ps=pi*FibCrackPar(i, 1)*FibCrackPar(i, 6)*(1+FibCrackPar(i, 8)*(FibCrackS(i, 3)-FibCrackS(i, 2))/FibCrackPar(i, 1))*(FibCrackS(i, 1)-FibCrackS(i, 3)+FibCrackS(i, 2))*exp(sc*FibCrackPar(i, 2))+(us-FibCrackS(i, 3))*((10*FibCrackPar(i, 4))*(pi*FibCrackPar(i, 1)^2/4));
					else Ps=0;
					end
				else % Loading
					if (us<=FibCrackS(i, 2)), Ps=sqrt((pi^2*FibCrackPar(i, 6)*FibCrackPar(i, 4)*FibCrackPar(i, 1)^3*(1+eta))/2*us+(pi^2*FibCrackPar(i, 7)*FibCrackPar(i, 4)*FibCrackPar(i, 1)^3*(1+eta))/2)*exp(sc*FibCrackPar(i, 2));
					elseif (us<=FibCrackS(i, 1)+FibCrackS(i, 2)), Ps=pi*FibCrackPar(i, 1)*FibCrackPar(i, 6)*(1+FibCrackPar(i, 8)*(us-FibCrackS(i, 2))/FibCrackPar(i, 1))*(FibCrackS(i, 1)-us+FibCrackS(i, 2))*exp(sc*FibCrackPar(i, 2));
					else Ps=0;
					end
				end
				
				% Long side
				if ((ul-FibCrackL(i, 3))<0) % unloading and reloading
					if (FibCrackL(i, 3)<=FibCrackL(i, 2)), Pl=sqrt((pi^2*FibCrackPar(i, 6)*FibCrackPar(i, 4)*FibCrackPar(i, 1)^3*(1+eta))/2*FibCrackL(i, 3)+(pi^2*FibCrackPar(i, 7)*FibCrackPar(i, 4)*FibCrackPar(i, 1)^3*(1+eta))/2)*exp(sc*FibCrackPar(i, 2))+(ul-FibCrackL(i, 3))*((10*FibCrackPar(i, 4))*(pi*FibCrackPar(i, 1)^2/4));
					elseif (FibCrackL(i, 3)<=FibCrackL(i, 1)+FibCrackL(i, 2)), Pl=pi*FibCrackPar(i, 1)*FibCrackPar(i, 6)*(1+FibCrackPar(i, 8)*(FibCrackL(i, 3)-FibCrackL(i, 2))/FibCrackPar(i, 1))*(FibCrackL(i, 1)-FibCrackL(i, 3)+FibCrackL(i, 2))*exp(sc*FibCrackPar(i, 2))+(ul-FibCrackL(i, 3))*((10*FibCrackPar(i, 4))*(pi*FibCrackPar(i, 1)^2/4));
					else Pl=0;
					end
				else % Loading
					if (ul<=FibCrackL(i, 2)), Pl=sqrt((pi^2*FibCrackPar(i, 6)*FibCrackPar(i, 4)*FibCrackPar(i, 1)^3*(1+eta))/2*ul+(pi^2*FibCrackPar(i, 7)*FibCrackPar(i, 4)*FibCrackPar(i, 1)^3*(1+eta))/2)*exp(sc*FibCrackPar(i, 2));
					elseif (ul<=FibCrackL(i, 1)+FibCrackL(i, 2)), Pl=pi*FibCrackPar(i, 1)*FibCrackPar(i, 6)*(1+FibCrackPar(i, 8)*(ul-FibCrackL(i, 2))/FibCrackPar(i, 1))*(FibCrackL(i, 1)-ul+FibCrackL(i, 2))*exp(sc*FibCrackPar(i, 2));
					else Pl=0;
					end
				end
				
				% Checking the balance of forces
				if ( abs(Ps-Pl) <= cc )
					OK=1;
				elseif ( (Ps-Pl) > 0 )
					if dus<0, dus=-dus/10; end
					us=us-dus; ul=COD-us;
				elseif ( (Ps-Pl) < 0 )
					if dus>0, dus=-dus/10; end
					us=us-dus; ul=COD-us;
				end
			end % end while
			
			% Evaluation
			if ( Ps/(pi*FibCrackPar(i, 1)^2/4) >= (FibCrackPar(i, 5)*exp(-src* FibCrackPar(i, 2)) ) || Pl/(pi*FibCrackPar(i, 1)^2/4) >= (FibCrackPar(i, 5)*exp(-src* FibCrackPar(i, 2)) ) )
				FibCrackIn(i, 1) = 1;
				Ps = 0; Pl = 0;
			elseif ( us > ( FibCrackS(i, 1) + FibCrackS(i, 2) ) )
				FibCrackIn(i, 2) = 1;
				Ps = 0; Pl = 0;
			end
			FibCrackS(i, 3) = max(us, FibCrackS(i, 3));
			FibCrackL(i, 3) = max(ul, FibCrackL(i, 3));
		else
			Ps=0; Pl=0;
		end % end for rupture and full pull-out
		P1=P1+Ps;
		P2=P2+Pl;
	end % end for n
	cohesion(j, 1) = COD;
	cohesion(j, 2) = P1;
	cohesion(j, 3) = P2;
	cohesion(j, 4) = sum(FibCrackIn(:, 1));
	cohesion(j, 5) = sum(FibCrackIn(:, 2));
	j = j+1;
end % end for COD

% toc